"""
This module contains the common PennyLane navigation bar data.
"""

NAVBAR_LEFT = [
    {
        "name": "Quantum machine learning",
        "href": "https://pennylane.ai/qml/",
    },
    {
        "name": "Demos",
        "href": "https://pennylane.ai/qml/demonstrations.html",
    },
    {
        "name": "Install",
        "href": "https://pennylane.ai/install.html",
    },
    {
        "name": "Plugins",
        "href": "https://pennylane.ai/plugins.html",
    },
    {
        "name": "Documentation",
        "href": "https://docs.pennylane.ai",
    },
    {
        "name": "Blog",
        "href": "https://pennylane.ai/blog/",
    },
    {
        "name": "<i class='fas fa-campground'></i> Code Camp",
        "href": "https://codecamp.xanadu.ai/",
    },
]


NAVBAR_RIGHT = [
    {
        "name": "FAQ",
        "href": "https://pennylane.ai/faq.html",
        "icon": "fas fa-question",
    },
    {
        "name": "Support",
        "href": "https://discuss.pennylane.ai/",
        "icon": "fab fa-discourse",
    },
    {
        "name": "GitHub",
        "href": "https://github.com/PennyLaneAI/pennylane",
        "icon": "fab fa-github",
    },
]
